class ConfigsController < ApplicationController
  before_action :sync_users
  before_action :set_model, only: [:update]
  before_action :set_targets, only: [:index]

  model_data_store(Config, { read: true, update: true }, { read: true, update: true })

  also_protect_with(RxModule::Authorization.verb('user_config_admin', 'Admin', [:index]))

  def check_authorization!
    return false if current_user.blank?
    return true unless params['action'] == 'index'

    RxModule::Authorization.current_user_can?('Config', 'user_config_admin') || super
  end

  def index
    @models
  end

  def read
    can_read_anyone = RxModule::Authorization.current_user_can?('Config', 'user_config_admin')
    if can_read_anyone
      @model = Config.find_by(user_id: params[:id])
      if @model.blank?
        render json: {error: 'Invalid User ID provided'}, status: :bad_request
      end
    else
      @model = Config.find_by(user_id: current_user[:id])
    end
  end

  def update
    can_edit_anyone = RxModule::Authorization.current_user_can?('Config', 'user_config_admin')
    if can_edit_anyone || @model.user_id.to_i == RxModule::Authorization.current_user[:id]
      if @model.update(model_params)
        render json: @model, status: :ok, location: @model
      else
        render json: @model.errors, status: :unprocessable_entity
      end
    else
      render json: {error: 'You do not have permission to update this config'}, status: :forbidden
    end
  end

  def set_last_known_customer
    the_config = Config.find_by(user_id: RxModule::Authorization.current_user[:id])
    the_config.update(last_known_customer_id: params.require(:customer_id))
  end

  def selected_summary_columns
    @model = Config.find_by(user_id: current_user[:id])
    result = {}
    
    unless @model.selected_order_columns == "[]"
      columns = @model.selected_order_columns
      columns.each do |column|
        result[column] = column.titleize
      end
    end

    render json: result
  end

  private

  def sync_users
    RxModule::Communicator::Hub.picker_users.each do |user|
      if Config.exists?(user_id: user[:id])
        Config.find_by(user_id: user[:id]).update_attributes(user_email: user[:email], user_name: user[:name])
      else
        Config.create(user_id: user[:id], user_name: user[:name], user_email: user[:email])
      end
    end
  end

  def set_model
    @model = Config.find(params[:id])
  end

  def model_params
    params.require(:config).permit(:pd, :default_frame_status, :default_job_type, :edge_frame, :account_number, :last_known_customer_id, :continuous_entry, :allow_personalization, :show_confirmation, customer_ids: [], selected_order_columns: [])
  end

  def model_type
    Config
  end
end
