import * as React from 'react';
import {observer} from 'mobx-react-lite';
import {useCustomerSelectionStore} from "../hooks/useCustomerSelectionStore";
import {LinearProgress, makeStyles} from "@material-ui/core";
import {SelectField} from "@rx-suite/ui";
import {Trans} from "@lingui/macro";

const useStyles = makeStyles(theme => ({
    wrapper: {
        paddingRight: theme.spacing(1),
        minWidth: '10rem',
        color: '#fff'
    }
}));

export const CurrentCustomerSelect: React.FunctionComponent = observer(() => {
    const store = useCustomerSelectionStore();
    const classes = useStyles();
    const options = store.userCustomers.map(c => {
        return {
            label: c.display_name,
            value: c.getId().toString()
        }
    });

    if (options.length === 0) {
        return <div className={classes.wrapper}>
            <Trans>No Customer</Trans>
        </div>
    } else if (options.length === 1) {
        return <div className={classes.wrapper}>
            {store.currentCustomer?.name || <LinearProgress/>}
        </div>
    } else {
        return <div className={classes.wrapper}>
            <SelectField
                value={store.currentCustomerId}
                onChange={store.handleCurrentCustomerChange}
                color={'#fff'}
                options={options}
            />
        </div>
    }
});