import * as React from 'react';
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {ButtonField, HintButton, SelectFileField} from "@rx-suite/ui";
import {red} from "@material-ui/core/colors";
import {useOrderEntryStore} from "../hooks/useOrderEntryStore";
import {observer} from "mobx-react-lite";

const useClasses = makeStyles(() => ({
    deleteButton: {
        backgroundColor: red[500]
    }
}))


export const TraceFileButton = observer(() => {
    const store = useOrderEntryStore();

    const classes = useClasses();
    const loading = store.loadingFrameTraceFile;
    const file = store.frameTraceFile;

    return(
        <Grid container>
            <Grid item xs={12}>
                <Typography><Trans>Or upload a trace file</Trans></Typography>
            </Grid>
            <Grid item>
                {file && <ButtonField text={"X"} onClick={store.handleRemoveTraceFile} className={classes.deleteButton} tooltip={t`Remove selected trace file`}/>}
                <SelectFileField
                    label={file ? `${t`File:`} ${file.name  || t`Unnamed`}` : t`Choose file`}
                    onDrop={store.handleDrop}
                    disabled={loading || store.shouldLockTraceUploadField}
                    buttonProps={{loading: loading, color: file ? 'primary' : 'secondary', disabled: store.shouldLockTraceUploadField}}/>
                <HintButton title={t`File Select`}
                            text={t`Upload a file with a supported trace format.`}
                            boxProps={{style: {display: 'inline-block'}}}/>
            </Grid>
        </Grid>
    )
});