import {action, computed, makeObservable, observable, reaction} from "mobx";
import {isArrayLike, Transport} from "@rx-suite/data";
import {ConfigStore, CurrentUserConfig} from "../stores/ConfigStore";
import {CustomerModel, CustomerStore} from "../stores/CustomerStore";
import {loginState} from "@rx-suite/stores";

class CustomerSelectionStore {
    @observable currentCustomerId = '';

    @action.bound
    setCurrentCustomer(newCustomerId: string) {
        this.currentCustomerId = newCustomerId.toString();
    }

    @action.bound
    handleCurrentCustomerChange(_name: string | undefined, newCustomerId: string | string[]) {
        let resolvedId = '';
        if (isArrayLike(newCustomerId)) {
            resolvedId = newCustomerId[0] || '';
        } else {
            resolvedId = newCustomerId as string || '';
        }

        this.setCurrentCustomer(resolvedId);

        try {
            Transport.fetch('/api/config/switch_cust', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                    customer_id: resolvedId
                })
            })
        } catch {
            console.warn('Last cust post failed');
        }
    }

    @computed get currentCustomer() {
        return CustomerStore.get(this.currentCustomerId);
    }

    @computed get userCustomers() {
        return CurrentUserConfig.get().customer_ids.map(id => CustomerStore.data.get(id.toString())).filter(c => !!c) as CustomerModel[];
    }

    @computed get noCustomers() {
        return (this.userCustomers.length === 0) &&
            !ConfigStore.isLoading &&
            (ConfigStore.fetchStatus !== 'none') &&
            !CustomerStore.isLoading &&
            (CustomerStore.fetchStatus !== 'none') &&
            !loginState.pending;
    }
}

export const customerSelectionStore = new CustomerSelectionStore();
makeObservable(customerSelectionStore);

reaction(() => {
        return customerSelectionStore.userCustomers.length;
    },
    () => {
        if (customerSelectionStore.userCustomers.length === 1) {
            customerSelectionStore.setCurrentCustomer(customerSelectionStore.userCustomers[0]!.getId());
        } else if (CurrentUserConfig.get().last_known_customer_id) {
            customerSelectionStore.setCurrentCustomer(CurrentUserConfig.get().last_known_customer_id);
        }
    });

// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
if (!window.rxstores) {
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    window.rxstores = {};
}
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
if (!window.rxstores.customer_selection_store) {
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    window.rxstores.customer_selection_store = customerSelectionStore;
}

export const useCustomerSelectionStore = () => {
    return customerSelectionStore;
}
