import * as React from 'react';
import { Dialog, DialogContent, DialogActions, Box } from '@material-ui/core';
import {observer} from "mobx-react-lite";
import {Levels} from "../../../stores/_FieldConstants";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {OpenInNew} from "@material-ui/icons";

type Props = {
    level: string
}

export const ModalFieldsWrapper: React.FunctionComponent<Props> = observer(({ level, children }) => {
    const [open, setOpen] = React.useState(false);

    const levelData = Levels[level];
    const label = levelData.label;

    const handleClose = React.useCallback(() => {
        setOpen(false);
    }, []);

    const handleOpen = React.useCallback(() => {
        setOpen(true);
    }, []);

    const buttonText = <Box display={"flex"} alignItems={"center"} justifyContent={"center"}>
        <Box marginRight={1}>{label}</Box>
        <OpenInNew/>
    </Box>

    return(
        <Box marginTop={2} marginBottom={2} display={"inline-block"}>
            <ButtonField text={buttonText} onClick={handleOpen} />
            <Dialog open={open} onClose={handleClose} maxWidth={"xl"} fullWidth>
                <DialogContent>
                    {children}
                </DialogContent>
                <DialogActions>
                    <ButtonField text={t`Close`} onClick={handleClose}/>
                </DialogActions>
            </Dialog>
        </Box>

    )
})