import * as React from 'react';
import {observer} from "mobx-react-lite";
import {useStockOrderStore} from "../../hooks/useStockOrderStore";
import {Dialog, DialogActions, DialogContent, DialogTitle, Grid, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {ButtonField, InputField, ModelForm, ModelInput} from "@rx-suite/ui";
import {StockOrderItemModel} from "../../stores/StockOrderItemStore";
import {LensFindOPCInput} from "./LensFindOPCInput";
import {Search} from "@material-ui/icons";

export const StockOrderLensDialog: React.FunctionComponent = observer(() => {
    const store = useStockOrderStore();

    const afterSubmit = React.useCallback(() => {
        store.hideLensDialog();
        store.resetStockItem();
    }, [store])

    return (
        <Dialog open={store.showingLensDialog} fullWidth maxWidth={"lg"}>
            <DialogTitle>
                <Trans>Add Lens</Trans>
            </DialogTitle>
            <DialogContent>
                <Grid container spacing={2}>
                    <Grid item xs={12}>
                        <ModelForm model={store.stockItem as StockOrderItemModel} suppressWrapper suppressRedirect suppressList suppressImportExport suppressMakeCopy submitText={t`Add Lens`} showServerErrorTop={false} afterSubmit={afterSubmit}>
                            <Grid container spacing={2}>
                                <Grid item xs={12}>
                                    <InputField
                                        label={t`Scan/Type OPC...`}
                                        value={store.opcLookupFieldValue}
                                        onChange={store.handleLensOPCChange}
                                        onEnterKey={store.commitOPCLookupField}
                                        disabled={store.fetchingLensCandidates}
                                        autoFocus={false}
                                        inputProps={{
                                            startAdornment: <Search/>
                                        }}
                                    />
                                    <Typography variant={'caption'} color={'error'}>{store.fetchingLensCandidatesError}</Typography>
                                </Grid>
                                <Grid item xs={3}>
                                    <ModelInput name={'description'} disabled/>
                                </Grid>
                                <Grid item xs={3}>
                                    <ModelInput name={'item_identifier'} disabled/>
                                </Grid>
                                <Grid item xs={3}>
                                    <ModelInput name={'item_type'} disabled/>
                                </Grid>
                                <Grid item xs={3}>
                                    <ModelInput name={'quantity'} type={"number"}/>
                                </Grid>
                            </Grid>
                        </ModelForm>
                    </Grid>
                </Grid>
            </DialogContent>
            <DialogActions>
                <ButtonField text={t`Close`} onClick={afterSubmit}/>
            </DialogActions>
        </Dialog>
    );
})