import * as React from 'react';
import {BreadModel, makeColumn, ModelTableDeleteButton} from "@rx-suite/ui";
import {StockOrderModel, StockOrderStore} from "../../stores/StockOrderStore";
import {StockOrderForm} from "./StockOrderForm";
import {t} from "@lingui/macro";
import {OrdersTabs} from "../OrdersTabs";
import moment from "moment";

export const StockOrdersBreadModel = () => {
    const dateFormat = (value: any) => {
        if (value) {
            return moment(value).format("YYYY-MM-DD")
        }

        return ""
    }
    const columns = React.useMemo(() => [
        makeColumn('order_number', t`Order Number`, "string"),
        makeColumn('po_number', t`PO Number`, "string"),
        makeColumn('reference_number', t`Reference Number`, "string"),
        makeColumn('shipping_method_code', t`Shipping Method`, "string"),
        makeColumn('date_completed', t`Date Completed`, "date", dateFormat),
        makeColumn('date_ordered', t`Date Ordered`, "date", dateFormat),
    ], [])

    return(
        <>
            <OrdersTabs />
            <BreadModel
                columns={columns}
                store={StockOrderStore}
                Form={StockOrderForm}
                mountEdit={false}
                tableProps={{
                    replacementActions: {
                        Delete: ({model: modelIn, store: storeIn}) => {
                            if ((modelIn as StockOrderModel).isOpen) return <ModelTableDeleteButton store={storeIn} model={modelIn}/>;
                            return null;
                        }
                    }
                }}
            />
        </>
    )
};
