import {attribute, DataStore, model, Model} from '@rx-suite/data/build';
import {t} from "@lingui/macro";
import { number } from 'yup'
import {action, override} from "mobx";

@model({
  transportLayer: "/api/stock_order_items",
  routingInfo: {
    create: "/stock_order_items/create",
    edit: "/stock_order_items/:id/edit"
  }
})
export class StockOrderItemModel extends Model {
  constructor() {
    super();
    super.setup();
  }

  @attribute({label: t`Description`})
  description = "";

  @attribute({label: t`Identifier`})
  item_identifier = "";

  @attribute({label: t`Item Type`})
  item_type = ""

  @attribute({label: t`Quantity`, validation: number().typeError("Quantity must be a valid number.").min(1).max(99999).required().integer('Quantity must be a whole number.')})
  quantity = 0

  @attribute()
  stock_order_id = ""

  @attribute({ label: t`Created At`, autoForm: false })
  created_at: Date = new Date();

  @attribute({ label: t`Updated At`, autoForm: false })
  updated_at: Date = new Date();

  @override
  resetView() {
    this.errors = {}
    if (this.isNew) {
      this.viewModel.description = ""
      this.viewModel.item_identifier = ""
      this.viewModel.quantity = 0;
      this.viewModel.stock_order_id = ""
    } else {
      super.resetView();
    }
    this.validate();
  }

}

export const StockOrderItemStore = StockOrderItemModel.store as DataStore<StockOrderItemModel>;
