import {attribute, DataStore, model, Model} from '@rx-suite/data';
import {t} from "@lingui/macro";
import moment from "moment";
import {computed, override} from "mobx";
import {string} from "yup";

@model({
  transportLayer: "/api/stock_orders",
  routingInfo: {
    list: "/stock_orders",
    create: "/stock_orders/create",
    read: "/stock_orders/:id/read"
  }
})
export class StockOrderModel extends Model {
  static types = {
    date_ordered: "date",
    date_completed: "date"
  }

  @attribute({label: t`Order Number`, description: t`The number generate by RxUniverse associated to the order`})
  order_number = ""

  @attribute({label: t`PO Number`, description: t`The purchase order number for this order`})
  po_number = ""

  @attribute({label: t`Reference Number`, description: t`A unique number that references this order.`, validation: string().when('isOpen', {
      is: false,
      then: schema => schema.optional(),
      otherwise: schema => schema.matches(/^[a-zA-Z0-9]*$/, { message: "Reference Number must be valid alphanumeric characters."}).max(21, 'Reference Number must not exceed 21 characters.').required('Reference Number is required.')
    })})
  reference_number = ""

  @attribute({label: t`Shipping Method`, description: t`The shipping method used to send this order out.`})
  shipping_method_id: string | null = "";

  @attribute({label: t`User`})
  user_id = ""

  @attribute({label: t`Status`, description: t`The Status of the order`})
  status = "open";

  @attribute({label: t`Customer`, validation: string().required('Customer is required.')})
  customer_id = "";

  @attribute({label: t`Date Completed`, description: t`The date when the order was submitted`})
  date_completed = ""

  @attribute({label: t`Date Ordered`, description: t`The initial date this order was created.`})
  date_ordered = moment();

  @attribute()
  shipping_method_code = "";

  @attribute({ label: t`Created At`, autoForm: false })
  created_at: Date = new Date();

  @attribute({ label: t`Updated At`, autoForm: false })
  updated_at: Date = new Date();

  @attribute({label: t`Release Number`, validation: string().max(20, 'Release Number must not exceed 21 characters.').nullable()})
  release_number = "";

  @computed
  get isOpen(){
    return this.status === "open";
  }

  @override
  resetView() {
    super.resetView();
    if (this.isNew) {
      this.errors = {}
      this.viewModel.reference_number = ""
      this.viewModel.po_number = ""
      this.viewModel.shipping_method_code = ""
      this.viewModel.release_number = ""
    }
  }

  constructor() {
    super();
    super.setup();
  }

}

export const StockOrderStore = StockOrderModel.store as DataStore<StockOrderModel>;
