# == Schema Information
#
# Table name: stock_order_items
#
#  id              :bigint           not null, primary key
#  description     :string(4000)
#  item_identifier :string(4000)
#  item_type       :string(4000)
#  quantity        :integer
#  created_at      :datetime         not null
#  updated_at      :datetime         not null
#  stock_order_id  :bigint
#
# Indexes
#
#  index_stock_order_items_on_stock_order_id  (stock_order_id)
#
# Foreign Keys
#
#  fk_rails_...  (stock_order_id => stock_orders.id)
#
class StockOrderItem < ApplicationRecord
  enum item_type: {frame: 'frame', lens: 'lens', misc: 'misc', other: 'other'}

  belongs_to :stock_order

  validate :stock_item_quantity_on_order, on: :create
  validates_uniqueness_of :item_identifier, scope: :stock_order_id, message: "is already part of this order. If you wish to add quantity, modify the current existing line."
  validates_numericality_of :quantity, :greater_than => 0, :less_than_or_equal_to => 99999

  RXU_TYPE_MAP = {
    S: "lens",
    F: "frame",
    M: "misc",
    O: "other"
  }

  def stock_item_quantity_on_order
    quantity = StockOrderItem.where(stock_order_id: self.stock_order_id).count
    if quantity >= 10
      errors.add(:base, "Cannot add this item, you've reached the maximum limit of 10 items on your order.")
    end
  end

  def self.load_from_rxuniverse(data, stock_order)
    item = find_or_create_by(item_identifier: data[:stockNumber], stock_order_id: stock_order.id)
    item.assign_attributes(
      description: data[:description],
      item_type: RXU_TYPE_MAP[data[:typeCode].to_sym],
      quantity: data[:quantity],
      stock_order: stock_order
    )
    item.save(validate: false)
  end
end
