# == Schema Information
#
# Table name: sync_statuses
#
#  id              :bigint           not null, primary key
#  error_message   :text(2147483647)
#  failed          :boolean
#  in_progress     :boolean
#  queued          :boolean
#  sync_ended_at   :datetime
#  sync_started_at :datetime
#  type            :string(4000)
#  created_at      :datetime         not null
#  updated_at      :datetime         not null
#
class SyncStatus < ApplicationRecord
  LIMIT = 250


  def self.instance
    first_or_create(type: self.name)
  end

  def self.reset!
    update_all(error_message: "", failed: false, in_progress: false, queued: false)
  end

  def broadcast_class_name
    "SyncStatus"
  end

  def controller_name
    "SyncStatusesController"
  end

  def to_partial_path
    "sync_statuses/sync_status"
  end

  def broadcast_local_name
    :sync_status
  end

  def humanized_name
    self.class.name.chomp("SyncStatus").titleize
  end

  def queue_sync
    update(queued: true)
  end

  def to_json(*args)
    JSON.generate(JSON.parse(super.as_json(*args)).merge(JSON.parse(render_jbuilder_partial)))
  end

  def self.wrap(&blk)
    sync_status = instance

    return if sync_status.in_progress?

    sync_status.update(queued: false, in_progress: true, sync_started_at: Time.now, failed: false)
    begin
      blk.call
    rescue StandardError => e
      sync_status.update(in_progress: false, failed: true, error_message: e.message)
      raise e
    ensure
      sync_status.update(in_progress: false, sync_ended_at: Time.now, queued: false)
    end
  end
end
